==> calamares-settings-solydxk_4.17%2Br13.tar.xz: source/ts/calamares-solydxk_da.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="da" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Tak for dit valg af SolydXK&lt;/h3&gt;&lt;br /&gt;Du har valgt en Linux-distribution der er:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Sikker og stabil&lt;/li&gt;&lt;li&gt;Hurtig og fleksibel&lt;/li&gt;&lt;li&gt;Klar til desktop-anvendelse&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Hav god fornøjelse med denne nye udgave og tak for dit valg af SolydXK.&lt;br /&gt;&lt;br /&gt;Installationen varer 15-30 minutter alt efter dine valg.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Vi står på skuldrene af giganter&lt;/h3&gt;&lt;br /&gt;SolydXK er en Debian-baseret GNU/Linux-distribution afledt af -og kompatibel med Debian.&lt;br /&gt;&lt;br /&gt;SolydXK anvender enten letvægts-skrivebordsmiljøet XFCE i SolydX eller det meget konfigurerbare og overraskende flotte KDE skrivebordsmiljø i SolydK.&lt;br /&gt;&lt;br /&gt;Vores nyskabelser, den hurtige udvikling i Debian og det enorme udvalg af programpakker i Debian gør SolydXK til et af de mest effektive desktop-operativsystemer der er tilgængelige til hjemmebrugeren.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Fra starten af&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, og LibreOffice er allerede installeret i SolydXK, så du kan med det samme bruge tekstbehandling og internet.&lt;br /&gt;&lt;br /&gt;Ulig andre distributioner kan SolydXK også allerede fra første start afspille musik, video&apos;er på internettet og meget mere.&lt;br /&gt;&lt;br /&gt;Et stor udvalg af programmer kan installeres blot med et museklik.&lt;br /&gt;&lt;br /&gt;SolydXK er kompatibel med de mest gængse filformater såsom: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, og mange andre.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Kontorprogrammerne er klar til brug så snart installationen af SolydXK er færdig&lt;/h3&gt;&lt;br /&gt;LibreOffice, en meget stærk kontorpakke er indbygget i SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice er nem at lære og nem at bruge.&lt;br /&gt;&lt;br /&gt;Du kan bruge den til breve, dias-præsentationer, regneark samt diagrammer og databaser.&lt;br /&gt;&lt;br /&gt;LibreOffice anvender som standard OpenDocument formatet og kan håndtere dokumenter fra f.eks. WordPerfect og Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.&lt;br /&gt;&lt;br /&gt;SolydXK can detect other operating systems and install itself beside them.You can choose which operating system to launch when you start the computer.</source>
        <translation>&lt;h3&gt;Et alternativ til de mest udbredte operativsystemer&lt;/h3&gt;&lt;br /&gt;SolydXK er let at bruge, kraftfuldt og konfigurerbart.&lt;br /&gt;&lt;br /&gt;SolydXK er sikkert og stabilt. Ulig andre operativsystemer er det ikke i samme grad sårbart overfor vira og spyware. Det lider ikke under fragmentation af filsystemerne og det har ikke nogen registreringsdatabase der jævnligt kræver oprydning.&lt;br /&gt;&lt;br /&gt;SolydXK kan detektere andre operativsystemer og installere sig selv ved siden af. Du kan så vælge hvilket du vil starte når du tænder maskinen.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="143"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Sikre opdateringer&lt;/h3&gt;&lt;br /&gt;Visse operativsystemer gør det sværere end nødvendigt at anvende maskinen. SolydXK mener at opdateringer skal foretages hurtigt, nemt og så bare ellers ikke være i vejen.&lt;br /&gt;&lt;br /&gt;Opdateringshåndtering ligger diskret i programlinjen og fortæller dig når der er kommet nye opdateringer. Du behøver ikke installere opdateringer hvis ikke du har tid eller lyst. Opdateringshåndtering vil ikke gentagne gange komme med pop-ups, forhindre dig i at genstarte, forsinke nedlukning af computeren eller på anden måde genere dig.&lt;br /&gt;&lt;br /&gt;Alle de opdaterede filer er nøje vedligeholdt og kontrolleret af betroede udviklere og vedligeholdelsesfolk.&lt;br /&gt;&lt;br /&gt;Alle filer gemmes i særligt sikrede repositorier hvor du kan hente dem.&lt;br /&gt;&lt;br /&gt;Sikkerhedsrepositoriet synkroniseres dagligt.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="165"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Et storartet brugermiljø&lt;/h3&gt;&lt;br /&gt;SolydXK-brugerne nyder at kunne dele deres passion og entusiasme og er meget villige til at hjælpe. Tøv ikke med at spørge i forummet eller blive engageret i miljøet.&lt;br /&gt;&lt;br /&gt;Send os gerne dine tilbagemeldinger og fortæl os om dine oplevelser. Vi lytter gerne til dine ideer og forslag og bruge dem til at forbedre SolydXK.</translation>
    </message>
</context>
</TS>

==> calamares-settings-solydxk_4.27%2Br13.tar.xz: source/ts/calamares-solydxk_da.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="da" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Tak for dit valg af SolydXK&lt;/h3&gt;&lt;br /&gt;Du har valgt en Linux-distribution der er:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Sikker og stabil&lt;/li&gt;&lt;li&gt;Hurtig og fleksibel&lt;/li&gt;&lt;li&gt;Klar til desktop-anvendelse&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Hav god fornøjelse med denne nye udgave og tak for dit valg af SolydXK.&lt;br /&gt;&lt;br /&gt;Installationen varer 15-30 minutter alt efter dine valg.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Vi står på skuldrene af giganter&lt;/h3&gt;&lt;br /&gt;SolydXK er en Debian-baseret GNU/Linux-distribution afledt af -og kompatibel med Debian.&lt;br /&gt;&lt;br /&gt;SolydXK anvender enten letvægts-skrivebordsmiljøet XFCE i SolydX eller det meget konfigurerbare og overraskende flotte KDE skrivebordsmiljø i SolydK.&lt;br /&gt;&lt;br /&gt;Vores nyskabelser, den hurtige udvikling i Debian og det enorme udvalg af programpakker i Debian gør SolydXK til et af de mest effektive desktop-operativsystemer der er tilgængelige til hjemmebrugeren.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Fra starten af&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, og LibreOffice er allerede installeret i SolydXK, så du kan med det samme bruge tekstbehandling og internet.&lt;br /&gt;&lt;br /&gt;Ulig andre distributioner kan SolydXK også allerede fra første start afspille musik, video&apos;er på internettet og meget mere.&lt;br /&gt;&lt;br /&gt;Et stor udvalg af programmer kan installeres blot med et museklik.&lt;br /&gt;&lt;br /&gt;SolydXK er kompatibel med de mest gængse filformater såsom: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, og mange andre.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Kontorprogrammerne er klar til brug så snart installationen af SolydXK er færdig&lt;/h3&gt;&lt;br /&gt;LibreOffice, en meget stærk kontorpakke er indbygget i SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice er nem at lære og nem at bruge.&lt;br /&gt;&lt;br /&gt;Du kan bruge den til breve, dias-præsentationer, regneark samt diagrammer og databaser.&lt;br /&gt;&lt;br /&gt;LibreOffice anvender som standard OpenDocument formatet og kan håndtere dokumenter fra f.eks. WordPerfect og Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.</source>
        <translation>&lt;h3&gt;Et alternativ til de mest udbredte operativsystemer&lt;/h3&gt;&lt;br /&gt;SolydXK er let at bruge, kraftfuldt og konfigurerbart.&lt;br /&gt;&lt;br /&gt;SolydXK er sikkert og stabilt. Ulig andre operativsystemer er det ikke i samme grad sårbart overfor vira og spyware. Det lider ikke under fragmentation af filsystemerne og det har ikke nogen registreringsdatabase der jævnligt kræver oprydning.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="142"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Sikre opdateringer&lt;/h3&gt;&lt;br /&gt;Visse operativsystemer gør det sværere end nødvendigt at anvende maskinen. SolydXK mener at opdateringer skal foretages hurtigt, nemt og så bare ellers ikke være i vejen.&lt;br /&gt;&lt;br /&gt;Opdateringshåndtering ligger diskret i programlinjen og fortæller dig når der er kommet nye opdateringer. Du behøver ikke installere opdateringer hvis ikke du har tid eller lyst. Opdateringshåndtering vil ikke gentagne gange komme med pop-ups, forhindre dig i at genstarte, forsinke nedlukning af computeren eller på anden måde genere dig.&lt;br /&gt;&lt;br /&gt;Alle de opdaterede filer er nøje vedligeholdt og kontrolleret af betroede udviklere og vedligeholdelsesfolk.&lt;br /&gt;&lt;br /&gt;Alle filer gemmes i særligt sikrede repositorier hvor du kan hente dem.&lt;br /&gt;&lt;br /&gt;Sikkerhedsrepositoriet synkroniseres dagligt.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="164"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Et storartet brugermiljø&lt;/h3&gt;&lt;br /&gt;SolydXK-brugerne nyder at kunne dele deres passion og entusiasme og er meget villige til at hjælpe. Tøv ikke med at spørge i forummet eller blive engageret i miljøet.&lt;br /&gt;&lt;br /&gt;Send os gerne dine tilbagemeldinger og fortæl os om dine oplevelser. Vi lytter gerne til dine ideer og forslag og bruge dem til at forbedre SolydXK.</translation>
    </message>
</context>
</TS>
